@@ -9,7 +9,7 @@ package Apache::OutputChain;
 use 5.004;
 use strict;
 use vars qw( $VERSION $DEBUG );
-$VERSION = 0.08;
+$VERSION = 0.09;
 
 use Apache::Constants ':common';
 $DEBUG = 0;
@@ -25,7 +25,8 @@ sub handler
 	print STDERR "    Apache::OutputChain tied $class -> ",
 		$reftied ? $reftied : 'STDOUT', "\n" if DEBUG;
 
-	untie *STDOUT;
+	### untie *STDOUT;
+	### this provoked untie attempted while 1 inner references still exist
 	tie *STDOUT, $class, $r;
 
 	if ($reftied eq 'Apache')	{ tie *STDOUT, $class, $r; }
@@ -125,11 +126,11 @@ will call I<PRINT> method of the next class.
 
 =head1 VERSION
 
-0.08
+0.09
 
 =head1 AUTHOR
 
-(c) 1997--1999 Jan Pazdziora, adelton@fi.muni.cz,
+(c) 1997--2002 Jan Pazdziora, adelton@fi.muni.cz,
 http://www.fi.muni.cz/~adelton/ at Faculty of Informatics, Masaryk
 University, Brno, Czech Republic
 
